From 2de557161c7d931fc787ef3e307e9e7014a9a52a Mon Sep 17 00:00:00 2001
From: John Alway <thaleslv@yahoo.com>
Date: Sat, 23 Nov 2019 14:12:05 -0600
Subject: [PATCH] comctl32/tests: Check combobox height after SetItemHeight
 SetWindowPos.

This bug happens when the message CB_SETITEMHEIGHT is followed by
SetWindowPos() for a combobox. This patch applies to the window
class "ComboBox" and not to "ComboBoxEx32".

Wine-Bug: https://bugs.winehq.org/show_bug.cgi?id=47489
Signed-off-by: John Alway <thaleslv@yahoo.com>
---
 dlls/comctl32/tests/combo.c | 28 ++++++++++++++++++++++++++++
 1 file changed, 28 insertions(+)

diff --git a/dlls/comctl32/tests/combo.c b/dlls/comctl32/tests/combo.c
index 4757fa3..a4cd8a5 100644
--- a/dlls/comctl32/tests/combo.c
+++ b/dlls/comctl32/tests/combo.c
@@ -1348,6 +1348,33 @@ static void test_combo_ctlcolor(void)
     DestroyWindow(combo);
 }
 
+static void test_combo_height_reset(void)
+{
+    HWND hCombo;
+    HFONT hFont;
+    int height1, height2;
+
+    /* This test requires the WC_COMBOBOXA style.  It won't work for WC_COMBOBOXEXA */
+    hCombo = CreateWindowExA(0, WC_COMBOBOXA, NULL, WS_BORDER | WS_VISIBLE | WS_CHILD | CBS_DROPDOWN, 0, 0, 300, 300,
+                                hComboExParentWnd, NULL, hMainHinst, NULL);
+
+    hFont = (HFONT)SendMessageA(hCombo, WM_GETFONT, 0, 0);
+    height1 = font_height(hFont);
+    height1 >>= 1;
+
+    /* Set Item Height followed by SetWindowPos() is the test */
+    SendMessageA(hCombo, CB_SETITEMHEIGHT, -1, height1);
+
+    /* SetWindowPos() should set the height according to font size*/
+    SetWindowPos(hCombo,NULL, 10,10,150,20, SWP_SHOWWINDOW);
+    height2 = SendMessageA(hCombo, CB_GETITEMHEIGHT, -1, 0);
+    todo_wine ok(height2 > (height1 + 2), "SetWindowPos() failed. Height (%d)\n", height2);
+
+    /* Cleanup */
+    DestroyWindow(hCombo);
+    DeleteObject(hFont);
+}
+
 START_TEST(combo)
 {
     ULONG_PTR ctx_cookie;
@@ -1392,6 +1419,7 @@ START_TEST(combo)
     test_combo_dropdown_size(0);
     test_combo_dropdown_size(CBS_NOINTEGRALHEIGHT);
     test_combo_ctlcolor();
+    test_combo_height_reset();
 
     cleanup();
     unload_v6_module(ctx_cookie, hCtx);
-- 
2.7.4

